@@ -1,17 +1,14 @@
 package NetHack::Item::Role::Lightable;
-our $VERSION = '0.10';
-
 use Moose::Role;
-use MooseX::AttributeHelpers;
 
 has is_lit => (
-    metaclass => 'Bool',
+    traits    => ['Bool'],
     is        => 'rw',
     isa       => 'Bool',
     default   => 0,
-    provides  => {
-        set   => 'light',
-        unset => 'extinguish',
+    handles   => {
+        light      => 'set',
+        extinguish => 'unset',
     },
 );
 
